;This demo provides an illustration on how to read and visualize PM25 in
; LGHAP dataset and write data into GeoTIFF in IDL.

; The demo was prepared with IDL8.5.

; Last updated: 2021-11-01
PRO read_LGHAP_PM25

  ;Determine compilation rules
  compile_opt idl2

  envi, /restore_base_save_files
  envi_batch_init

  ;Set output path
  CD, 'D:\'
  outpath = 'D:\test\'
  ; read PM25 data from NetCDF file


  filearr = dialog_pickfile(/multiple_files,  title = 'Open the original nc file')

  num = n_elements(filearr)


  FOR i=0,num-1,1 DO BEGIN

    file_ID = ncdf_open(filearr, /nowrite )


    latid = NCDF_VARID(file_ID,'lat')       ;read latitude from NetCDF file
    NCDF_VARGET, file_ID, latid, lat
    nlat = N_ELEMENTS(lat)

    lonid = NCDF_VARID(file_ID,'lon')       ;read  longitude from NetCDF file
    NCDF_VARGET, file_ID, lonid, lon
    nlon = N_ELEMENTS(lon)

    PM25id = NCDF_VARID(file_ID,'PM25')        ; read PM25 data
    NCDF_VARGET, file_ID, PM25id, PM25
    nAOD = N_ELEMENTS(AOD)
    ;Obtain the gain, offset, and fill values of PM25 data, and perform calibration
    ncdf_attget,file_ID,PM25id,'scale_factor',a
    ncdf_attget,file_ID,PM25id,'add_offset',b
    ncdf_attget,file_ID,PM25id,'_FillValue',fv
    fv_index = where(PM25 eq fv)
    output_PM25 = (PM25 ne fv)*PM25*a+b
    ; define fillvalue
    output_PM25[fv_index] =-999

    ;visualization

    loadct, 33
    TVLCT, r, g, b, /get
    color_table = BYTARR(3, 256)
    color_table[0, *] = r
    color_table[1, *] = g
    color_table[2, *] = b
    color_table[*, 0] = [255, 255, 255]  ;Custom colorbar

    img=image(transpose(output_PM25),rgb_table=color_table,title=file,grid_units=2,POSITION=[0.1,0.15,0.9,0.95],map_projection='geographic', image_dimensions=[max(lon)-min(lon),max(lat)-min(lat)] ,$
      IMAGE_LOCATION=[min(lon),min(lat)],DIMENSIONS=[691,512])

    ;set colormap limits
    img.MAX_VALUE=100
    img.MIN_VALUE=0
    ;Change the figure title, grid type, axis text direction, and color bar form
    img.title = 'Date:'+strmid(file_basename(filearr),17,8)

    img.mapgrid.label_position=0
    img.mapgrid.font_name='Palatino'

    img.mapgrid.linestyle=6
    img.mapgrid.horizon_thick=1


    lons=img.mapgrid.longitudes
    lats=img.mapgrid.latitudes
    for lons_i=0,n_elements(lons)-1 do begin
      lons[lons_i].label_angle=0
      lons[lons_i].label_align=0
    endfor

    ; add colorbar
    c = COLORBAR(TARGET=img, ORIENTATION=1,TITLE='PM2.5',POSITION=[0.905,0.25,0.925,0.85])
    c.RANGE=[0,100]

    c.BORDER=0
    c.TICKDIR= 1
    c.TEXTPOS = 1

    ;save plot in jpg format with resolution
    Img.save,outpath+'LGHAP.PM25.D001.A'+strmid(file_basename(filearr),17,8)+'.jpg'
    ; save as GeoTIFF
    ;Write geographic information structure
    geo_info={$
      MODELPIXELSCALETAG:[0.01,0.01,0.0],$
      MODELTIEPOINTTAG:[0.0,0.0,0.0,min(lon),max(lat),0.0],$
      GTMODELTYPEGEOKEY:2,$
      GTRASTERTYPEGEOKEY:1,$
      GEOGRAPHICTYPEGEOKEY:4326,$
      GEOGCITATIONGEOKEY:'GCS_WGS_1984'}

    ;write GeoTIFF
    WRITE_TIFF,outpath+'LGHAP.PM25.D001.A'+strmid(file_basename(filearr),16,8)+'.tif',reverse(transpose(output_PM25),2),/float, geotiff=geo_info
    ;Close nc file ID
    NCDF_CLOSE, file_ID
  endfor

END
