# This demo provides an illustration on how to read and visualize PM10 in
# LGHAP dataset and write data into GeoTIFF in RStudio.
# 
# four libraries (ncdf4,raster,rgdal and ggplot2) are needed
# 
# The demo was prepared with R.
# 
# Last updated: 2021-11-01
# install.packages

library(ncdf4) # package for netcdf manipulation
library(raster) # package for raster manipulation
library(rgdal) # package for geospatial analysis
library(ggplot2) # package for plotting

# set your path
setwd('K:/PM25_longterm_production/stepx_format_pubilc_dataset')

## (a) read PM10 data from NetCDF file
# the nc file to be read
filename = "LGHAP.PM10.D001.Axxxxxxxx.nc"
ncdata = nc_open(filename)

# extract date from filename
date = substr(filename,regexpr('\\d{8}',filename),regexpr('\\d{8}',filename)+7)

# read longitude and latitude from NetCDF file
lon = ncvar_get(ncdata,'lon')
lat = ncvar_get(ncdata,'lat')

# read PM10 data
PM10 = ncvar_get(ncdata,'PM10')

# close nc file
nc_close(ncdata)

## (b) visualzation
# convert PM10 to raster in memory
r = raster(PM10, xmn=min(lon), xmx=max(lon), ymn=min(lat), ymx=max(lat), crs=CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs+ towgs84=0,0,0"))
r = flip(r, direction='y')

# plot PM10 and save plot in jpg format with resolution of 300 DPI
savename = paste(c('LGHAP.PM10.D001.A',date,'.jpg'),collapse = '')
jpeg(file = savename,width = 5000,height = 4000,res = 300)
r2 = r
r2[r2>2]=2
plot(r2,col=topo.colors(100),main=paste(c("PM10 Date: ",date),collapse = ''),zlim=c(0,300),xlab = "Longitude", ylab = "Latitude",cex.axis=1.5,cex.lab=1.5,cex.main=2)
dev.off()

## (c) save as GeoTIFF
# write GeoTIFF
nc2raster = stack(r)
savename = paste(c('LGHAP.PM10.D001.A',date,'.tif'),collapse = '')
writeRaster(nc2raster,savename,format = 'GTiff',overwrite = TRUE)
