% This demo provides an illustration on how to read and visualize AOD in
% LGHAP dataset and write data into GeoTIFF in MATLAB.
%
% The demo was prepared with MATLAB R2020b.
%
% Last updated: 2021-11-01

%% (a) read AOD data from NetCDF file

% the nc file to be read
filename = 'LGHAP.AOD.D001.Axxxxxxxx.nc';

% read longitude and latitude from NetCDF file
lon = ncread(filename,'lon');
lat = ncread(filename,'lat');

% read AOD data
AOD = ncread(filename,'AOD');

%% (b) visualization

% create georeference struct to map AOD data on projected datum
R = georefcells([14.995,56.005],[70.995,139.005],[4100,6800]);
latlim = R.LatitudeLimits;
lonlim = R.LongitudeLimits;

% load coastlines
load coastlines

% plot data
pos = get(0,'ScreenSize');

figure('color','w','position',[50,50,round(pos(3)*0.5),round(pos(4)*0.5)]);

worldmap(latlim,lonlim)

% plot coastline
geoshow(coastlat,coastlon,'Color','k')

% plot AOD
geoshow(AOD,R,'DisplayType','surface');

% set colormap limits
caxis([0,2]);

% set colors used to map data
colormap('Jet');

% add colorbar
h = colorbar();
h.Label.String = 'AOD';
h.FontSize = 14;
setm(gca,'FontSize',14);

% add title to the plot 
title(['Date',string(regexp(filename,'\d{8}','match'))],'FontSize',14);

% save plot in jpg format with resolution of 300 DPI
savename = ['LGHAP.AOD.D001.A' char(string(regexp(filename,'\d{8}','match'))) '.jpg'];
print(savename,'-djpeg','-r300');

%% (c) save as GeoTIFF

% define fillvalue
Fillvalue = -999;
AOD_tiff = AOD;
AOD_tiff(isnan(AOD_tiff)) = Fillvalue;

% write GeoTIFF
savename = ['LGHAP.AOD.D001.A' char(string(regexp(filename,'\d{8}','match'))) '.tif'];
geotiffwrite(savename,AOD_tiff,R);
