% This demo provides an illustration on how to read and visualize PM25 in
% LGHAP dataset and write data into GeoTIFF in MATLAB.
%
% The demo was prepared with MATLAB R2020b.
%
% Last updated: 2021-11-01

%% (a) read PM25 data from NetCDF file

% the nc file to be read
filename = 'LGHAP.PM25.D001.Axxxxxxxx.nc';

% read longitude and latitude from NetCDF file
lon = ncread(filename,'lon');
lat = ncread(filename,'lat');

% read PM25 data
PM25 = ncread(filename,'PM25');

%% (b) visualization

% create georeference struct to map PM25 data on projected datum
R = georefcells([14.995,56.005],[70.995,139.005],[4100,6800]);
latlim = R.LatitudeLimits;
lonlim = R.LongitudeLimits;

% load coastlines
load coastlines

% plot data
pos = get(0,'ScreenSize');

figure('color','w','position',[50,50,round(pos(3)*0.5),round(pos(4)*0.5)]);

worldmap(latlim,lonlim)

% plot coastline
geoshow(coastlat,coastlon,'Color','k')

% plot PM25
geoshow(PM25,R,'DisplayType','surface');

% set colormap limits
caxis([0,100]);

% set colors used to map data
colormap('Jet');

% add colorbar
h = colorbar();
h.Label.String = 'PM2.5';
h.FontSize = 14;
setm(gca,'FontSize',14);

% add title to the plot 
title(['Date',string(regexp(filename,'\d{8}','match'))],'FontSize',14);

% save plot in jpg format with resolution of 300 DPI
savename = ['LGHAP.PM25.D001.A' char(string(regexp(filename,'\d{8}','match'))) '.jpg'];
print(savename,'-djpeg','-r300');

%% (c) save as GeoTIFF

% define fillvalue
Fillvalue = -999;
PM25_tiff = PM25;
PM25_tiff(isnan(PM25_tiff)) = Fillvalue;

% write GeoTIFF
savename = ['LGHAP.PM25.D001.A' char(string(regexp(filename,'\d{8}','match'))) '.tif'];
geotiffwrite(savename,PM25_tiff,R);
